API Reference
=============

The API Reference provides an overview of all public objects,
functions and methods implemented in SpiPy.
All classes and function exposed in ``spires.*``
namespace plus those listed in the reference are public.


.. automodsumm:: spires.interpolator
   :template: instance_methods.rst

.. automodsumm:: spires.invert
   :template: instance_methods.rst

.. automodsumm:: spires.process
   :template: instance_methods.rst

.. automodsumm:: spires.utol
   :template: instance_methods.rst

.. automodsumm:: spires.legacy
   :template: instance_methods.rst

.. automodule:: spires.interpolator
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: spires.invert
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: spires.process
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: spires.utol
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: spires.legacy
   :members:
   :undoc-members:
   :show-inheritance: